==> android-4.0.1.2-sources.jar: android/widget/ToggleButton.java <==
package android.widget;
public class ToggleButton
  extends android.widget.CompoundButton
{
public  ToggleButton(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  ToggleButton(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  ToggleButton(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  void setChecked(boolean checked) { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getTextOn() { throw new RuntimeException("Stub!"); }
public  void setTextOn(java.lang.CharSequence textOn) { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getTextOff() { throw new RuntimeException("Stub!"); }
public  void setTextOff(java.lang.CharSequence textOff) { throw new RuntimeException("Stub!"); }
protected  void onFinishInflate() { throw new RuntimeException("Stub!"); }
public  void setBackgroundDrawable(android.graphics.drawable.Drawable d) { throw new RuntimeException("Stub!"); }
protected  void drawableStateChanged() { throw new RuntimeException("Stub!"); }
public  void onPopulateAccessibilityEvent(android.view.accessibility.AccessibilityEvent event) { throw new RuntimeException("Stub!"); }
}

==> android-4.1.1.4-sources.jar: android/widget/ToggleButton.java <==
package android.widget;
public class ToggleButton
  extends android.widget.CompoundButton
{
public  ToggleButton(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  ToggleButton(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  ToggleButton(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  void setChecked(boolean checked) { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getTextOn() { throw new RuntimeException("Stub!"); }
public  void setTextOn(java.lang.CharSequence textOn) { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getTextOff() { throw new RuntimeException("Stub!"); }
public  void setTextOff(java.lang.CharSequence textOff) { throw new RuntimeException("Stub!"); }
protected  void onFinishInflate() { throw new RuntimeException("Stub!"); }
public  void setBackgroundDrawable(android.graphics.drawable.Drawable d) { throw new RuntimeException("Stub!"); }
protected  void drawableStateChanged() { throw new RuntimeException("Stub!"); }
public  void onInitializeAccessibilityEvent(android.view.accessibility.AccessibilityEvent event) { throw new RuntimeException("Stub!"); }
public  void onInitializeAccessibilityNodeInfo(android.view.accessibility.AccessibilityNodeInfo info) { throw new RuntimeException("Stub!"); }
}
